kedro.runner — Kedro 0.17.6 documentation

# kedro.runner

Description

`kedro.runner` provides runners that are able to execute `Pipeline` instances.

Functions

`kedro.runner.run_node`(node, catalog[, …]) | Run a single Node with inputs from and outputs to the catalog.

Classes

`kedro.runner.AbstractRunner`([is_async]) | `AbstractRunner` is the base class for all `Pipeline` runner implementations.
`kedro.runner.ParallelRunner`([max_workers, …]) | `ParallelRunner` is an `AbstractRunner` implementation.
`kedro.runner.SequentialRunner`([is_async]) | `SequentialRunner` is an `AbstractRunner` implementation.
`kedro.runner.ThreadRunner`([max_workers, …]) | `ThreadRunner` is an `AbstractRunner` implementation.